import request from '../request'
import qs from 'qs'

let fileCommonApiUrl='/student/film/order/fileCommonApi'

//电影模块API
const cinema = {
	/**
	 * 获取电影后台折扣参数
	 * @param {Object} data
	 */
	getFilmDiscount(data) {
		return request({
			url: `/system/config/configKey/film_discount`,
		})
	},
	/**
	 * 获取即将上映电影列表
	 * @param {Object} data
	 */
	getSoonList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-soon-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 包含某电影的日期
	 * @param {Object} data
	 */
	getShowDate(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-show-date',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 获取正在热映电影列表
	 * @param {Object} data
	 */
	getHotList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-hot-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 获取城市列表
	 * @param {Object} data
	 */
	getCityList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-city-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 获取影院列表
	 * @param {Object} data
	 */
	getCinemaList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-cinema-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 包含某电影的影院
	 * @param {Object} data
	 */
	getShowList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-show-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 某电影在某影院的场次排期
	 * @param {Object} data
	 */
	getScheduleList(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-schedule-list',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 查账户余额
	 * @param {Object} data
	 */
	getInfo(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'api/user/info',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 根据订单查影票信息
	 * @param {Object} data
	 */
	orderQuery(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'api/order/query',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 某次电影的座位
	 * @param {Object} data
	 */
	getSeat(data) {
		return request({
			url: fileCommonApiUrl,
			method: 'post',
			data: {
				url: 'movieapi/movie-info/get-seat',
				paramData: qs.stringify(data)
			}
		})
	},
	/**
	 * 获取电影票支付数据
	 * @param {Object} data
	 */
	prepareOrder(data) {
		return request({
			url: '/student/wx/prepareOrder',
			method: 'post',
			data
		})
	}
}

export default cinema 

